%global pkgname guava

Name:           gap-pkg-%{pkgname}
Version:        3.14
Release:        2%{?dist}
Summary:        Computing with error-correcting codes

License:        GPLv2 or GPLv3
URL:            https://gap-packages.github.io/guava/
Source0:        https://github.com/gap-packages/guava/archive/v%{version}/%{pkgname}-%{version}.tar.gz
# Enable the optional Sonata code.  Upstream says to uncomment this code if
# Sonata is available, and that is all this patch does.
Patch0:         %{name}-sonata.patch
# Patch to fix C compiler warnings that indicate possible runtime problems.
Patch1:         %{name}-warning.patch
# Use popcount instructions where available.
Patch2:         %{name}-popcount.patch

BuildRequires:  gap-devel
BuildRequires:  GAPDoc-latex
BuildRequires:  gap-pkg-sonata
BuildRequires:  gcc
BuildRequires:  parallel
BuildRequires:  procps
BuildRequires:  texlive-collection-basic

Requires:       gap-core
Requires:       gap-pkg-sonata

%description
GUAVA is a package that implements coding theory algorithms in GAP.
Codes can be created and manipulated and information about codes can be
calculated.

GUAVA consists of various files written in the GAP language, and an
external program from J. S. Leon for dealing with automorphism groups of
codes and isomorphism testing functions.  Several algorithms that need
the speed are integrated in the GAP kernel.

The functions within GUAVA can be divided into four categories:
- Construction of codes.  GUAVA can construct non-linear, linear and
  cyclic codes over an arbitrary finite field.  Examples are
  HadamardCode, ReedMullerCode, BestKnownLinearCode, QRCode and
  GoppaCode.
- Manipulation of codes.  These functions allow the user to transform
  one code into another or to construct a new code from two codes.
  Examples are PuncturedCode, DualCode, DirectProductCode and UUVCode.
- Computation of information about codes.  This information is stored in
  the code record.  Examples are MinimumDistance, OuterDistribution,
  IsSelfDualCode and AutomorphismGroup.
- Generation of bounds on linear codes.  The table by Brouwer and
  Verhoeff (as it existed in the mid-1990s) is incorporated into GUAVA.
  For example, BoundsMinimumDistance.

%prep
%setup -q -n %{pkgname}-%{version}
%patch0
%patch1
%patch2

# Avoid name collisions in the documentation
cp -p src/ctjhai/README README.ctjhai

%build
# This is NOT an autoconf-generated script.  Do not use %%configure.
./configure %{_gap_dir}

# Building with %%{?_smp_mflags} fails
make CFLAGS="%{optflags} -DLONG_EXTERNAL_NAMES" LDFLAGS="$RPM_LD_FLAGS"

# Compress large tables
parallel %{?_smp_mflags} --no-notice gzip --best ::: tbl/*.g

# Link to main GAP documentation
ln -s %{_gap_dir}/doc ../../doc
mkdir ../pkg
ln -s ../%{pkgname}-%{version} ../pkg/%{pkgname}
gap -l "$PWD/..;%{_gap_dir}" makedoc.g
rm -fr ../../doc ../pkg
pushd src/leon/doc
pdftex manual.tex
popd

%install
mkdir -p %{buildroot}%{_gap_dir}/pkg
cp -a ../%{pkgname}-%{version} %{buildroot}%{_gap_dir}/pkg/%{pkgname}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/{CHANGES.guava,configure,COPYING.guava,HISTORY.guava,Makefile*,README.*}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc/*.{aux,bbl,blg,brf,idx,ilg,ind,log,out,pnr,tex,toc}
rm -fr %{buildroot}%{_gap_dir}/pkg/%{pkgname}/src

%check
# The documentation tests cannot be run, as they require breaking out of
# infinite loops.  See comments about a user interrupt.
cd tst
gap -l "%{buildroot}%{_gap_dir};%{_gap_dir}" << EOF 2>&1 | tee log
LoadPackage("guava");
Test("guava.tst", rec( compareFunction := "uptowhitespace" ) );
Test("decoding.tst", rec( compareFunction := "uptowhitespace" ) );
Test("hadamard.tst", rec( compareFunction := "uptowhitespace" ) );
Test("table.tst", rec( compareFunction := "uptowhitespace" ) );
EOF
! grep -Fq fail log
rm -f log

%files
%doc CHANGES.guava HISTORY.guava README.guava README.md README.ctjhai
%doc src/leon/doc/manual.pdf
%license COPYING.guava
%docdir %{_gap_dir}/pkg/%{pkgname}/doc
%docdir %{_gap_dir}/pkg/%{pkgname}/htm
%{_gap_dir}/pkg/%{pkgname}/

%changelog
* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.14-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Thu Mar 29 2018 Jerry James <loganjerry@gmail.com> - 3.14-1
- New upstream version
- Drop upstreamed -bibtex patch

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.13.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.13.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.13.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.13.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Jan  6 2017 Jerry James <loganjerry@gmail.com> - 3.13.1-3
- Fix a broken submake command

* Fri Aug 19 2016 Jerry James <loganjerry@gmail.com> - 3.13.1-2
- More compiler warnings fixed

* Tue Aug 16 2016 Jerry James <loganjerry@gmail.com> - 3.13.1-1
- Initial RPM
